@@ -1,16 +1,22 @@
 """
-Version 0.3.0 (in development)
+Version 0.3.1 (in development)
 ==============================
 
 A Python implementation of the Unity Engine
 that supports different types of windows.
 Still in development.
 
+Installation
+------------
+The first step in using PyUnity is always
+installing it. To install pyunity, simply run
+
+    pip install pyunity
+
 Importing
 ---------
-The first step in using PyUnity is always
-importing it. A standard way to import is like
-so:
+To start using pyunity, you must import it.
+A standard way to import is like so:
 
     >>> from pyunity import *
 
@@ -24,7 +30,7 @@ This is the output with debugging::
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.3.0
+    Loaded PyUnity version 0.3.1
 
 If debugging is off, there is no output:
 
@@ -107,7 +113,7 @@ To run an example, import it like so:
     FreeGLUT doesn't work, trying GLFW
     GLFW doesn't work, trying Pygame
     Using window provider Pygame
-    Loaded PyUnity version 0.3.0
+    Loaded PyUnity version 0.3.1
     >>> main()
 
 Or from the command line::
@@ -134,7 +140,7 @@ from .quaternion import Quaternion
 from .vector3 import Vector3
 from .meshes import Mesh
 import os
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 __copyright__ = "Copyright 2020 Ray Chen"
 __email__ = "tankimarshal2@gmail.com"
 __license__ = "MIT License"
